// 回到顶部组件Func
function scrollIt(destination, duration, easing, callback) {
  var easings = {
    easeInOutQuart: function (t) {
      return t < 0.5 ? 8 * t * t * t * t : 1 - 8 * --t * t * t * t;
    }
  };

  (function () {
    var lastTime = 0;
    var vendors = ["webkit", "o"];
    for (var x = 0; x < vendors.length && !window.requestAnimationFrame; ++x) {
      window.requestAnimationFrame =
        window[vendors[x] + "RequestAnimationFrame"];
      window.cancelAnimationFrame =
        window[vendors[x] + "CancelAnimationFrame"] ||
        window[vendors[x] + "CancelRequestAnimationFrame"];
    }

    if (!window.requestAnimationFrame)
      window.requestAnimationFrame = function (callback, element) {
        var currTime = new Date().getTime();
        var timeToCall = Math.max(0, 16 - (currTime - lastTime));
        var id = window.setTimeout(function () {
          callback(currTime + timeToCall);
        }, timeToCall);
        lastTime = currTime + timeToCall;
        return id;
      };

    if (!window.cancelAnimationFrame)
      window.cancelAnimationFrame = function (id) {
        clearTimeout(id);
      };
  })();

  function checkElement() {
    document.documentElement.scrollTop += 1;
    var elm =
      document.documentElement.scrollTop !== 0
        ? document.documentElement
        : document.body;
    document.documentElement.scrollTop -= 1;
    return elm;
  }

  var element = checkElement();
  var start = element.scrollTop;
  var startTime = Date.now();

  function scroll() {
    var now = Date.now();
    var time = Math.min(1, (now - startTime) / duration);
    var timeFunction = easings[easing](time);
    element.scrollTop = timeFunction * (destination - start) + start;

    if (element.scrollTop === destination) {
      callback;
      return;
    }
    window.requestAnimationFrame(scroll);
  }
  scroll();
}

// 回到顶部组件
Vue.component('mkreturntop', {
  props: {
    pageY: {
      type: Number,
      default: 100
    },
    transitionName: {
      type: String,
      default: 'easeInOutQuart'
    }
  },
  data: function () {
    return {
      showTooltips: false,
      showReturnToTop: false
    }
  },
  methods: {
    currentPageYOffset: function () {
      window.pageYOffset > this.pageY ? this.showReturnToTop = true : this.showReturnToTop = false
    },
    backToTop: function () {
      scrollIt(0, 100, this.transitionName, this.currentPageYOffset);
    },
  },
  template: "<p class='backTop' @click='backToTop' v-show='showReturnToTop' style='z-index: 100000000;bottom: 60px;'><span class='icon iconfont icon-4fanhuidingbucheng' style='color: #fff !important;font-size: 25px;'></span></p>",
  created: function () {
    window.addEventListener('scroll', this.currentPageYOffset);
  },
  beforeDestroy: function () {
    window.removeEventListener('scroll', this.currentPageYOffset)
  },

})
